@@ -1,12 +1,11 @@
-from dnastack.cli.utils import assert_config
 from dnastack.client import *
 from .tables import commands as tables_commands
+from ..utils import get_config
 
 
 @click.group()
-@click.pass_context
-def collections(ctx):
-    assert_config(ctx, "collections-url", str)
+def collections():
+    pass
 
 
 @collections.command(name="list")
@@ -15,13 +14,14 @@ def list_collections(ctx):
     try:
         click.echo(
             json.dumps(
-                collections_client.list_collections(ctx.obj["collections-url"]),
+                collections_client.list_collections(get_config(ctx, "collections.url")),
                 indent=4,
             )
         )
-    except:
+    except Exception as e:
         click.secho(
-            f"Error occurred while listing collections from collection [{ctx.obj['collections-url']}]",
+            f"Error occurred while listing collections from collections url "
+            f"[{get_config(ctx, 'collections.url')}]: {e}",
             fg="red",
         )
         sys.exit(1)
@@ -43,7 +43,7 @@ def query_collection(ctx, collection_name, query, format="json"):
     try:
         click.echo(
             collections_client.query(
-                ctx.obj["collections-url"],
+                get_config(ctx, "collections.url"),
                 collection_name,
                 query,
                 format=format,
@@ -51,7 +51,8 @@ def query_collection(ctx, collection_name, query, format="json"):
         )
     except Exception as e:
         click.secho(
-            f"Error occurred while querying collection [{collection_name}] from collections-url [{ctx.obj['collections-url']}]: {e}",
+            f"Error occurred while querying collection [{collection_name}] from collections url "
+            f"[{get_config(ctx, 'collections.url')}]: {e}",
             fg="red",
         )
         sys.exit(1)
