@@ -1,12 +1,11 @@
 from .tables import commands as tables_commands
-from dnastack.cli.utils import assert_config, get_config
+from dnastack.cli.utils import get_config
 from dnastack.client import *
 
 
 @click.group()
-@click.pass_context
-def dataconnect(ctx):
-    assert_config(ctx, "data-connect-url", str)
+def dataconnect():
+    pass
 
 
 @dataconnect.command()
@@ -26,7 +25,7 @@ def query(ctx, q, download, raw, format="json"):
     try:
         click.echo(
             dataconnect_client.query(
-                get_config(ctx, "data-connect-url", str),
+                get_config(ctx, "data_connect.url", str),
                 q,
                 download,
                 "csv"
@@ -38,7 +37,7 @@ def query(ctx, q, download, raw, format="json"):
         )
     except Exception as e:
         click.secho(
-            f"Unable to query [{get_config(ctx, 'data-connect-url', str)}]: {e}"
+            f"Unable to query [{get_config(ctx, 'data_connect.url', str)}]: {e}"
         )
         sys.exit(1)
 
