@@ -1,6 +1,6 @@
 import click
-from dnastack.cli.auth import get_oauth_token
-from dnastack.cli.utils import get_auth_params, get_config
+from ...auth import get_oauth_token
+from ...utils import get_auth_params, get_config
 from dnastack.client import *
 
 
@@ -31,8 +31,8 @@ def runs_execute(
 ):
     engine_param = None
     tag_param = None
-    oauth_token = get_oauth_token(ctx)
-    auth_params = get_auth_params(ctx, True)
+    oauth_token = get_oauth_token(ctx, wallet_url=get_config(ctx, "wes.wallet.url"))
+    auth_params = get_auth_params(ctx, service="wes", use_default=True)
 
     if engine_parameter:
         engine_param = __parse_key_value_param(engine_parameter, "engine-parameter")
@@ -42,7 +42,7 @@ def runs_execute(
 
     try:
         result = wes_client.submit_workflow(
-            get_config(ctx=ctx, var_name="wes-url", do_assert=True),
+            get_config(ctx=ctx, var_path="wes.url"),
             workflow_url,
             oauth_token,
             auth_params,
@@ -59,7 +59,7 @@ def runs_execute(
 
         click.echo(json.dumps(result, indent=4))
     except Exception as e:
-        click.secho(str(e), fg="red")
+        click.secho(f"Unable to execute {workflow_url}: {e}", fg="red")
         sys.exit(1)
 
 
@@ -82,13 +82,13 @@ def __parse_key_value_param(parameter, param_name):
 @click.option("-t", "--page-token", required=False, default=None)
 @click.option("--all", is_flag=True, required=False)
 def runs_list(ctx, page_size, page_token, all):
-    oauth_token = get_oauth_token(ctx)
-    auth_params = get_auth_params(ctx, True)
+    oauth_token = get_oauth_token(ctx, wallet_url=get_config(ctx, "wes.wallet.url"))
+    auth_params = get_auth_params(ctx, service="wes", use_default=False)
 
     try:
         if all:
             response = wes_client.get_list_of_workflows_executed(
-                get_config(ctx=ctx, var_name="wes-url", do_assert=True),
+                get_config(ctx=ctx, var_path="wes.url"),
                 oauth_token,
                 auth_params,
                 None,
@@ -96,7 +96,7 @@ def runs_list(ctx, page_size, page_token, all):
             )
         else:
             response = wes_client.get_list_of_workflows_executed(
-                get_config(ctx=ctx, var_name="wes-url", do_assert=True),
+                get_config(ctx=ctx, var_path="wes.url"),
                 oauth_token,
                 auth_params,
                 page_size,
@@ -114,5 +114,5 @@ def runs_list(ctx, page_size, page_token, all):
             click.echo("wes runs list --page-token " + response["next_page_token"])
 
     except Exception as e:
-        click.secho(str(e), fg="red")
+        click.secho(f"Unable to list runs: {e}", fg="red")
         sys.exit(1)
