@@ -20,7 +20,7 @@ def handle_client_results(results, dataconnect_url):
         yield from results
     except SSLError:
         raise Exception(
-            f"There was an error retrieving the SSL certificate from {dataconnect_url}"
+            f"There was an error retrieving the SSL certificate from [{dataconnect_url}]"
         )
     except HTTPError as e:
         error_res = requests.get(e.response.url)
